# The mypacks Package
This package contains simpler, faster, and more efficient functions and codes.

##mathfun
- 1. addAll
###Usage: 
This function can be used to add number of numbers.

###Parameters/Arguments:
You can pass a number or number of numbers by separaring with commas.
you can also pass list, tuple or array using astrics(*) operator as prefix for parameter/argument
##author
aspurgs
